Crate light_sdk_types

Crate light_sdk_types 

light-sdk-types

Core types for the Light Protocol SDK.

TypeDescription
RentSponsorPDA to sponsor rent-exemption of Solana accounts using the Light Token Program
CpiAccountsContainer for CPI system and tree accounts
CpiSignerProgram ID, signer, and bump for CPI invocation
addressAddress derivation functions (v1 and v2)
constantsProtocol program IDs and discriminators

Re-exports

pub use crate::lca::CpiSigner;
pub use light_account_checks;
pub use constants::*;

Modules

address
constants
cpi_accounts
cpi_context_write
error
instruction
lca
Vendored compressed-account types
pack_accounts
Utilities for packing accounts into instruction data.
types
Re-export boundary for the vendored compressed-account types consumed by light-sdk.

Structs

RentSponsor

Traits

AnchorDeserialize
A data-structure that can be de-serialized from binary format by NBOR.
AnchorSerialize
A data-structure that can be serialized into binary format by NBOR.
LightDiscriminator

Derive Macros

AnchorDeserialize

AnchorSerialize