light-sdk-types
Core types for the Light Protocol SDK.
| Type | Description |
|---|---|
RentSponsor | PDA to sponsor rent-exemption of Solana accounts using the Light Token Program |
CpiAccounts | Container for CPI system and tree accounts |
CpiSigner | Program ID, signer, and bump for CPI invocation |
address | Address derivation functions (v1 and v2) |
constants | Protocol program IDs and discriminators |
Re-exports
pub use light_account_checks;pub use constants::*;
Modules
- address
- constants
- cpi_
accounts - cpi_
context_ write - error
- instruction
- interface
- Framework-agnostic interface for Light Protocol compressible accounts.
- pack_
accounts - Utilities for packing accounts into instruction data.
Structs
- CpiSigner
- Configuration struct containing program ID, CPI signer, and bump for Light Protocol
- Rent
Sponsor
Traits
- Anchor
Deserialize - A data-structure that can be de-serialized from binary format by NBOR.
- Anchor
Serialize - A data-structure that can be serialized into binary format by NBOR.
- Light
Discriminator